.. _ydoc directive_3:

``directive_3``
===============

Directive 3 has a lot of nesting

Subdirectives:

.. toctree::
   :maxdepth: 1

   directive_3/directive_3_1
   directive_3/directive_3_2


----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.